package com.ruoyi.system.service.columns.impl;

import java.util.List;

import com.ruoyi.system.domain.columns.YjAppreciate;
import com.ruoyi.system.mapper.colums.YjAppreciateMapper;
import com.ruoyi.system.service.columns.IYjAppreciateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 瑜伽欣赏Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
@Service
public class YjAppreciateServiceImpl implements IYjAppreciateService
{
    @Autowired
    private YjAppreciateMapper yjAppreciateMapper;

    /**
     * 查询瑜伽欣赏
     * 
     * @param id 瑜伽欣赏主键
     * @return 瑜伽欣赏
     */
    @Override
    public YjAppreciate selectYjAppreciateById(String id)
    {
        return yjAppreciateMapper.selectYjAppreciateById(id);
    }

    /**
     * 查询瑜伽欣赏列表
     * 
     * @param yjAppreciate 瑜伽欣赏
     * @return 瑜伽欣赏
     */
    @Override
    public List<YjAppreciate> selectYjAppreciateList(YjAppreciate yjAppreciate)
    {
        return yjAppreciateMapper.selectYjAppreciateList(yjAppreciate);
    }

    /**
     * 新增瑜伽欣赏
     * 
     * @param yjAppreciate 瑜伽欣赏
     * @return 结果
     */
    @Override
    public int insertYjAppreciate(YjAppreciate yjAppreciate)
    {
        return yjAppreciateMapper.insertYjAppreciate(yjAppreciate);
    }

    /**
     * 修改瑜伽欣赏
     * 
     * @param yjAppreciate 瑜伽欣赏
     * @return 结果
     */
    @Override
    public int updateYjAppreciate(YjAppreciate yjAppreciate)
    {
        return yjAppreciateMapper.updateYjAppreciate(yjAppreciate);
    }

    /**
     * 批量删除瑜伽欣赏
     * 
     * @param ids 需要删除的瑜伽欣赏主键
     * @return 结果
     */
    @Override
    public int deleteYjAppreciateByIds(String[] ids)
    {
        return yjAppreciateMapper.deleteYjAppreciateByIds(ids);
    }

    /**
     * 删除瑜伽欣赏信息
     * 
     * @param id 瑜伽欣赏主键
     * @return 结果
     */
    @Override
    public int deleteYjAppreciateById(String id)
    {
        return yjAppreciateMapper.deleteYjAppreciateById(id);
    }
}
